#[repr(transparent)]pub struct NotificationsSettings {
inner: TypedObjectRef<NotificationsSettings, ()>,
phantom: PhantomData<()>,
}Expand description
The notifications settings of a Session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<NotificationsSettings, ()>phantom: PhantomData<()>Implementations
Sourceimpl NotificationsSettings
impl NotificationsSettings
Sourcepub fn set_session<'a>(
&self,
value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_session<'a>( &self, value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>, )
The parent Session.
Sourcepub fn account_enabled(&self) -> <Cell<bool> as Property>::Value
pub fn account_enabled(&self) -> <Cell<bool> as Property>::Value
Whether notifications are enabled for this Matrix account.
Sourcepub fn session_enabled(&self) -> <Cell<bool> as Property>::Value
pub fn session_enabled(&self) -> <Cell<bool> as Property>::Value
Whether notifications are enabled for this session.
Sourcepub fn set_session_enabled<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_session_enabled<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether notifications are enabled for this session.
Sourcepub fn global_setting(
&self,
) -> <Cell<NotificationsGlobalSetting> as Property>::Value
pub fn global_setting( &self, ) -> <Cell<NotificationsGlobalSetting> as Property>::Value
The global setting about which messages trigger notifications.
Sourcepub fn keywords_list(&self) -> <StringList as Property>::Value
pub fn keywords_list(&self) -> <StringList as Property>::Value
The list of keywords that trigger notifications.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_account_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_account_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the account-enabled property
Sourcepub fn connect_session_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session-enabled property
Sourcepub fn connect_global_setting_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_global_setting_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the global-setting property
Sourcepub fn connect_keywords_list_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_keywords_list_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the keywords-list property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_account_enabled(&self)
pub fn notify_account_enabled(&self)
Notify listeners of a change in the account-enabled property
Sourcepub fn notify_session_enabled(&self)
pub fn notify_session_enabled(&self)
Notify listeners of a change in the session-enabled property
Sourcepub fn notify_global_setting(&self)
pub fn notify_global_setting(&self)
Notify listeners of a change in the global-setting property
Sourcepub fn notify_keywords_list(&self)
pub fn notify_keywords_list(&self)
Notify listeners of a change in the keywords-list property
Sourceimpl NotificationsSettings
impl NotificationsSettings
Sourcepub(crate) async fn set_account_enabled(
&self,
enabled: bool,
) -> Result<(), NotificationSettingsError>
pub(crate) async fn set_account_enabled( &self, enabled: bool, ) -> Result<(), NotificationSettingsError>
Set whether notifications are enabled for this session.
Sourcepub(crate) async fn set_global_setting(
&self,
setting: NotificationsGlobalSetting,
) -> Result<(), NotificationSettingsError>
pub(crate) async fn set_global_setting( &self, setting: NotificationsGlobalSetting, ) -> Result<(), NotificationSettingsError>
Set the global setting about which messages trigger notifications.
Sourcepub(crate) async fn remove_keyword(
&self,
keyword: String,
) -> Result<(), NotificationSettingsError>
pub(crate) async fn remove_keyword( &self, keyword: String, ) -> Result<(), NotificationSettingsError>
Remove a keyword from the list.
Sourcepub(crate) async fn add_keyword(
&self,
keyword: String,
) -> Result<(), NotificationSettingsError>
pub(crate) async fn add_keyword( &self, keyword: String, ) -> Result<(), NotificationSettingsError>
Add a keyword to the list.
Sourcepub(crate) async fn set_per_room_setting(
&self,
room_id: OwnedRoomId,
setting: NotificationsRoomSetting,
) -> Result<(), NotificationSettingsError>
pub(crate) async fn set_per_room_setting( &self, room_id: OwnedRoomId, setting: NotificationsRoomSetting, ) -> Result<(), NotificationSettingsError>
Set the notification setting for the room with the given ID.